@@ -5,7 +5,7 @@ use utf8;
 
 package App::GUI::Juliagraph;
 our $NAME = __PACKAGE__;
-our $VERSION = '0.4';
+our $VERSION = '0.41';
 
 use base qw/Wx::App/;
 use App::GUI::Juliagraph::Frame;
@@ -81,10 +81,10 @@ will be put into the variable C and in Julia fraktals into the variable
 z_0 (initial values of the iterator variable).
 
 =for HTML <p>
-<img src="https://raw.githubusercontent.com/lichtkind/App-GUI-Juliagraph/main/img/examples/first.png"         alt=""  width="300" height="300">
-<img src="https://raw.githubusercontent.com/lichtkind/App-GUI-Juliagraph/main/img/examples/first_detail.jpg"  alt=""  width="300" height="300">
-<img src="https://raw.githubusercontent.com/lichtkind/App-GUI-Juliagraph/main/img/examples/neat.png"          alt=""  width="300" height="300">
-<img src="https://raw.githubusercontent.com/lichtkind/App-GUI-Juliagraph/main/img/examples/julia.png"         alt=""  width="300" height="300">
+<img src="https://raw.githubusercontent.com/lichtkind/App-GUI-Juliagraph/master/img/examples/first.png"         alt=""  width="300" height="300">
+<img src="https://raw.githubusercontent.com/lichtkind/App-GUI-Juliagraph/master/img/examples/first_detail.jpg"  alt=""  width="300" height="300">
+<img src="https://raw.githubusercontent.com/lichtkind/App-GUI-Juliagraph/master/img/examples/neat.png"          alt=""  width="300" height="300">
+<img src="https://raw.githubusercontent.com/lichtkind/App-GUI-Juliagraph/master/img/examples/julia.png"         alt=""  width="300" height="300">
 </p>
 
 
@@ -130,7 +130,7 @@ at the bottom that appear while browsing the menu.
 =head2 Form
 
 =for HTML <p>
-<img src="https://raw.githubusercontent.com/lichtkind/App-GUI-Harmonograph/main/img/POD/Form.png"    alt=""  width="630" height="410">
+<img src="https://raw.githubusercontent.com/lichtkind/App-GUI-Juliagraph/master/img/POD/Form.png"    alt=""  width="630" height="410">
 </p>
 
 The content of the first tab are the settings that define the shape of the fractal.
@@ -177,7 +177,7 @@ iteration variable Z and y is the imaginary part.
 =head2 Color Mapping
 
 =for HTML <p>
-<img src="https://raw.githubusercontent.com/lichtkind/App-GUI-Harmonograph/main/img/POD/Mapping.png"    alt=""  width="630" height="410">
+<img src="https://raw.githubusercontent.com/lichtkind/App-GUI-Juliagraph/master/img/POD/Mapping.png"    alt=""  width="630" height="410">
 </p>
 
 On the second tab we have three rows of settings which determine how the
@@ -210,7 +210,7 @@ and repeat this process the ordered amount of times.
 =head2 Colors
 
 =for HTML <p>
-<img src="https://raw.githubusercontent.com/lichtkind/App-GUI-Harmonograph/main/img/POD/Color.png"    alt=""  width="630" height="410">
+<img src="https://raw.githubusercontent.com/lichtkind/App-GUI-Juliagraph/master/img/POD/Color.png"    alt=""  width="630" height="410">
 </p>
 
 This page helps you to select the color that will be used to paint the fractal.
